@@ -77,14 +77,12 @@ class TestRunAnsiblePlaybook(TestCase):
             utils.run_ansible_playbook,
             'non-existing.yaml',
             'localhost,',
-            utils.constants.DEFAULT_WORK_DIR
+            '/tmp'
         )
-        mock_exists.assert_called_with(os.path.join(
-            utils.constants.DEFAULT_WORK_DIR, 'non-existing.yaml'))
+        mock_exists.assert_called_with('/tmp/non-existing.yaml')
         mock_run.assert_not_called()
 
-    @mock.patch('tempfile.mkstemp', return_value=('foo', os.path.join(
-        utils.constants.DEFAULT_WORK_DIR, 'fooBar.cfg')))
+    @mock.patch('tempfile.mkstemp', return_value=('foo', '/tmp/fooBar.cfg'))
     @mock.patch('os.path.exists', return_value=True)
     @mock.patch('os.makedirs')
     @mock.patch.object(
@@ -101,11 +99,10 @@ class TestRunAnsiblePlaybook(TestCase):
             utils.run_ansible_playbook(
                 'existing.yaml',
                 'localhost,',
-                utils.constants.DEFAULT_WORK_DIR
+                '/tmp'
             )
 
-    @mock.patch('tempfile.mkstemp', return_value=('foo', os.path.join(
-        utils.constants.DEFAULT_WORK_DIR, 'fooBar.cfg')))
+    @mock.patch('tempfile.mkstemp', return_value=('foo', '/tmp/fooBar.cfg'))
     @mock.patch('os.path.exists', return_value=True)
     @mock.patch('os.makedirs')
     @mock.patch.object(
@@ -120,7 +117,7 @@ class TestRunAnsiblePlaybook(TestCase):
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR
+            workdir='/tmp'
         )
 
     @mock.patch('os.path.exists', return_value=True)
@@ -137,11 +134,10 @@ class TestRunAnsiblePlaybook(TestCase):
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR
+            workdir='/tmp'
         )
 
-    @mock.patch('tempfile.mkstemp', return_value=('foo', os.path.join(
-        utils.constants.DEFAULT_WORK_DIR, 'fooBar.cfg')))
+    @mock.patch('tempfile.mkstemp', return_value=('foo', '/tmp/fooBar.cfg'))
     @mock.patch('os.path.exists', return_value=True)
     @mock.patch('os.makedirs')
     @mock.patch.object(
@@ -157,13 +153,12 @@ class TestRunAnsiblePlaybook(TestCase):
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR,
+            workdir='/tmp',
             connection='local'
         )
 
     @mock.patch('os.makedirs', return_value=None)
-    @mock.patch('tempfile.mkstemp', return_value=('foo', os.path.join(
-        utils.constants.DEFAULT_WORK_DIR, 'fooBar.cfg')))
+    @mock.patch('tempfile.mkstemp', return_value=('foo', '/tmp/fooBar.cfg'))
     @mock.patch('os.path.exists', return_value=True)
     @mock.patch.object(
         Runner,
@@ -178,14 +173,13 @@ class TestRunAnsiblePlaybook(TestCase):
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR,
+            workdir='/tmp',
             connection='local',
             gathering_policy='smart'
         )
 
     @mock.patch('os.makedirs', return_value=None)
-    @mock.patch('tempfile.mkstemp', return_value=('foo', os.path.join(
-        utils.constants.DEFAULT_WORK_DIR, 'fooBar.cfg')))
+    @mock.patch('tempfile.mkstemp', return_value=('foo', '/tmp/fooBar.cfg'))
     @mock.patch('os.path.exists', return_value=True)
     @mock.patch.object(
         Runner,
@@ -202,7 +196,7 @@ class TestRunAnsiblePlaybook(TestCase):
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR,
+            workdir='/tmp',
             connection='local',
             gathering_policy='smart',
             extra_vars=arglist
@@ -218,29 +212,26 @@ class TestRunAnsiblePlaybook(TestCase):
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR,
+            workdir='/tmp',
             timeout=42
         )
-        self.assertIn(mock.call(os.path.join(utils.constants.DEFAULT_WORK_DIR,
-                                             'env/settings'), 'w'),
+        self.assertIn(mock.call('/tmp/env/settings', 'w'),
                       mock_open.mock_calls)
         self.assertIn(
             mock.call().__enter__().write('job_timeout: 2520\n'),  # 42m * 60
             mock_open.mock_calls)
 
-    @mock.patch('os.chmod')
     @mock.patch('six.moves.builtins.open')
     @mock.patch('tripleoclient.utils.makedirs')
     @mock.patch('os.path.exists', side_effect=(False, True, True))
-    def test_run_with_extravar_file(self, mock_exists, mock_mkdir, mock_open,
-                                    mock_chmod):
+    def test_run_with_extravar_file(self, mock_exists, mock_mkdir, mock_open):
         ansible_runner.ArtifactLoader = mock.MagicMock()
         ansible_runner.Runner.run = mock.MagicMock(return_value=('', 0))
         ansible_runner.runner_config = mock.MagicMock()
         utils.run_ansible_playbook(
             playbook='existing.yaml',
             inventory='localhost,',
-            workdir=utils.constants.DEFAULT_WORK_DIR,
+            workdir='/tmp',
             extra_vars_file={
                 'foo': 'bar',
                 'things': {
@@ -250,8 +241,7 @@ class TestRunAnsiblePlaybook(TestCase):
             }
         )
         self.assertIn(
-            mock.call(os.path.join(utils.constants.DEFAULT_WORK_DIR,
-                                   'env/extravars'), 'w'),
+            mock.call('/tmp/env/extravars', 'w'),
             mock_open.mock_calls
         )
         self.assertIn(
@@ -1234,16 +1224,23 @@ class ProcessMultipleEnvironments(TestCase):
                                             self.user_tht_root)
 
         mock_hc_process.assert_has_calls([
-            mock.call(env_path='./inside.yaml'),
-            mock.call(env_path='/twd/templates/abs.yaml'),
-            mock.call(env_path='/twd/templates/puppet/foo.yaml'),
-            mock.call(env_path='/twd/templates/environments/myenv.yaml'),
-            mock.call(env_path='/tmp/thtroot42/notouch.yaml'),
-            mock.call(env_path='./tmp/thtroot/notouch2.yaml'),
-            mock.call(env_path='../outside.yaml')])
+            mock.call(env_path='./inside.yaml',
+                      include_env_in_files=False),
+            mock.call(env_path='/twd/templates/abs.yaml',
+                      include_env_in_files=False),
+            mock.call(env_path='/twd/templates/puppet/foo.yaml',
+                      include_env_in_files=False),
+            mock.call(env_path='/twd/templates/environments/myenv.yaml',
+                      include_env_in_files=False),
+            mock.call(env_path='/tmp/thtroot42/notouch.yaml',
+                      include_env_in_files=False),
+            mock.call(env_path='./tmp/thtroot/notouch2.yaml',
+                      include_env_in_files=False),
+            mock.call(env_path='../outside.yaml',
+                      include_env_in_files=False)])
 
     @mock.patch('heatclient.common.template_utils.'
-                'process_environment_and_files', return_value=({}, {}),
+                'process_environment_and_files',
                 autospec=True)
     @mock.patch('heatclient.common.template_utils.'
                 'get_template_contents', return_value=({}, {}),
@@ -1292,7 +1289,7 @@ class ProcessMultipleEnvironments(TestCase):
 
         utils.process_multiple_environments(self.created_env_files,
                                             self.tht_root,
-                                            self.user_tht_root, False)
+                                            self.user_tht_root, None, False)
 
         mock_yaml_dump.assert_has_calls([mock.call(rewritten_env,
                                         default_flow_style=False)])
@@ -1795,23 +1792,18 @@ class TestGeneralUtils(base.TestCommand):
 
     def setUp(self):
         super(TestGeneralUtils, self).setUp()
-        self.tc = self.app.client_manager.tripleoclient = mock.Mock()
-        obj = self.tc.object_store = mock.Mock()
-        obj.put_object = mock.Mock()
-        obj.put_container = mock.Mock()
 
-    def test_update_deployment_status(self):
+    @mock.patch('tripleoclient.utils.safe_write')
+    def test_update_deployment_status(self, mock_write):
         mock_status = {
-            'status_update': 'TESTING',
             'deployment_status': 'TESTING'
         }
         utils.update_deployment_status(
-            self.app.client_manager,
             'overcloud',
-            mock_status
+            mock_status,
+            ''
         )
-        self.tc.object_store.put_object.assert_called()
-        self.tc.object_store.put_container.assert_called()
+        mock_write.assert_called()
 
     def test_playbook_limit_parse(self):
         limit_nodes = 'controller0, compute0:compute1,!compute2'
