@@ -34,44 +34,7 @@ class TestParameterWorkflows(utils.TestCommand):
 
     def setUp(self):
         super(TestParameterWorkflows, self).setUp()
-        self.app.client_manager.workflow_engine = self.workflow = mock.Mock()
-        self.orchestration = mock.Mock()
-        self.tripleoclient = mock.Mock()
-        self.tripleoclient.object_store = mock.MagicMock()
-        self.app.client_manager.tripleoclient = self.tripleoclient
-        self.app.client_manager.orchestration = self.orchestration
         self.app.client_manager.baremetal = mock.Mock()
-        self.app.client_manager.compute = mock.Mock()
-        execution = mock.Mock()
-        execution.id = "IDID"
-        self.workflow.executions.create.return_value = execution
-        get_container = self.tripleoclient.object_store.get_container \
-            = mock.MagicMock()
-        get_container.return_value = ('container', [{'name': 'f1'}])
-
-        flatten = mock.patch(
-            'tripleo_common.utils.stack_parameters.get_flattened_parameters',
-            autospec=True,
-            return_value={
-                'environment_parameters': {
-                    'TestParameter1': {},
-                    'TestRole1': 'TestParameter2'
-                },
-                'heat_resource_tree': {
-                    'parameters': {
-                        'TestParameter2': {
-                            'name': 'TestParameter2',
-                            'tags': [
-                                'role_specific'
-                            ]
-                        }
-                    },
-                    'resources': {}
-                }
-            }
-        )
-        flatten.start()
-        self.addCleanup(flatten.stop)
 
     @mock.patch('yaml.safe_load')
     @mock.patch("six.moves.builtins.open")
@@ -95,7 +58,10 @@ class TestParameterWorkflows(utils.TestCommand):
         parameters.invoke_plan_env_workflows(
             self.app.client_manager,
             'overcloud',
-            'the-plan-environment.yaml'
+            'the-plan-environment.yaml',
+            stack_data=mock.Mock(),
+            role_list=mock.Mock(),
+            derived_environment_path=mock.Mock()
         )
         calls = [
             mock.call(
@@ -104,7 +70,12 @@ class TestParameterWorkflows(utils.TestCommand):
                 workdir=mock.ANY,
                 playbook_dir=mock.ANY,
                 verbosity=0,
-                extra_vars={'num_phy_cores_per_numa_node_for_pmd': 2}
+                extra_vars_file={
+                    'tripleo_get_flatten_params': {
+                        'stack_data': mock.ANY},
+                    'tripleo_role_list': {'roles': mock.ANY}},
+                extra_vars={'num_phy_cores_per_numa_node_for_pmd': 2,
+                            'derived_environment_path': mock.ANY}
             )
         ]
         mock_playbook.assert_has_calls(calls, any_order=True)
@@ -134,7 +105,10 @@ class TestParameterWorkflows(utils.TestCommand):
         parameters.invoke_plan_env_workflows(
             self.app.client_manager,
             'overcloud',
-            'the-plan-environment.yaml'
+            'the-plan-environment.yaml',
+            stack_data=mock.Mock(),
+            role_list=mock.Mock(),
+            derived_environment_path=mock.Mock()
         )
         calls = [
             mock.call(
@@ -143,7 +117,12 @@ class TestParameterWorkflows(utils.TestCommand):
                 workdir=mock.ANY,
                 playbook_dir=mock.ANY,
                 verbosity=0,
-                extra_vars={'num_phy_cores_per_numa_node_for_pmd': 2}
+                extra_vars_file={
+                    'tripleo_get_flatten_params': {
+                        'stack_data': mock.ANY},
+                    'tripleo_role_list': {'roles': mock.ANY}},
+                extra_vars={'num_phy_cores_per_numa_node_for_pmd': 2,
+                            'derived_environment_path': mock.ANY}
             ),
             mock.call(
                 playbook='sample-playbook-2.yaml',
@@ -151,51 +130,16 @@ class TestParameterWorkflows(utils.TestCommand):
                 workdir=mock.ANY,
                 playbook_dir='/playbook/dir-1',
                 verbosity=0,
-                extra_vars={'some_opt': 0}
+                extra_vars_file={
+                    'tripleo_get_flatten_params': {
+                        'stack_data': mock.ANY},
+                    'tripleo_role_list': {'roles': mock.ANY}},
+                extra_vars={'some_opt': 0,
+                            'derived_environment_path': mock.ANY}
             )
         ]
         mock_playbook.assert_has_calls(calls, any_order=True)
 
-    def test_check_deprecated_params_no_output(self):
-        parameters.check_deprecated_parameters(
-            self.app.client_manager,
-            container='container-name')
-
-    def test_check_deprecated_params_user_defined(self):
-        with mock.patch('tripleoclient.workflows.parameters.LOG') as mock_log:
-            parameters.check_deprecated_parameters(
-                self.app.client_manager,
-                container='container-name')
-            self.assertTrue(mock_log.warning.called)
-
-    def test_check_deprecated_params_user_not_defined(self):
-        with mock.patch('tripleoclient.workflows.parameters.LOG') as mock_log:
-            parameters.check_deprecated_parameters(
-                self.app.client_manager,
-                container='container-name')
-            self.assertFalse(mock_log.log.warning.called)
-
-    def test_check_deprecated_multiple_parameters(self):
-        with mock.patch('tripleoclient.workflows.parameters.LOG') as mock_log:
-            parameters.check_deprecated_parameters(
-                self.app.client_manager,
-                container='container-name')
-            self.assertTrue(mock_log.warning.called)
-
-    def test_check_unused_multiple_parameters(self):
-        with mock.patch('tripleoclient.workflows.parameters.LOG') as mock_log:
-            parameters.check_deprecated_parameters(
-                self.app.client_manager,
-                container='container-name')
-            self.assertTrue(mock_log.warning.called)
-
-    def test_check_invalid_role_specific_parameters(self):
-        with mock.patch('tripleoclient.workflows.parameters.LOG') as mock_log:
-            parameters.check_deprecated_parameters(
-                self.app.client_manager,
-                container='container-name')
-            self.assertTrue(mock_log.warning.called)
-
     @mock.patch(
         'tripleo_common.utils.stack_parameters.generate_fencing_parameters',
         return_value={})
@@ -210,7 +154,6 @@ class TestParameterWorkflows(utils.TestCommand):
             'ipmi_lanplus': True
         }
         params = parameters.generate_fencing_parameters(
-            self.app.client_manager,
             **workflow_input
         )
         self.assertEqual(params, {"parameter_defaults": {}})
